==> nmail-php-patch-2.3.0-to-2.3.1.tgz: nmail/mail_move_ok.php <==
<?
require_once('include/global.php');
require_once('include/mail_lib.php');
require_once('include/file.php');
require_once('conf.inc.php');

page_loading_view(" ̵ϰ ֽϴ.");

// check
	// б⿡ ̵
	if (!$_POST && $_GET)
		$_POST = $_GET;

	if (!$_POST['mb_id'] || (!$_POST['mf_no'] && !$_POST['cmf']) || !$_POST['sel_mail_box'])
		msg('ùٸ URL Ͽ ֽʽÿ');


// data
	// set data
		$mail_file_table = $AUTH[auth_m_mf_table];

	$mf_no = array();
	if (getarraycount($_POST['cmf']) > 0)
	{
		$mf_no = $_POST['cmf'];
	} else
	{
		$mf_no[] = $_POST['mf_no'];
	}	// if()


// [2007-11-15]  ڵз
	$msg = '';
	if ($_POST['cmd'] == 'AUTO_FILTER')
	{
		require_once('include/auto_filter_lib.php');

		//  ϵ ּ 
		$mf_from = array();
		$mf_from_ori = array();
		$mf_from_addr = array();
		$mf_from_insert = array();
		$mf_from_exists = array();
		for ($i=0; $i<sizeof($mf_no); $i++)
		{
			$q = "SELECT mf_from FROM " . $mail_file_table . " WHERE mf_no='" . $mf_no[$i] . "' AND m_no='" . $AUTH['auth_m_no'] . "' AND mb_id='". $_POST['mb_id']. "'";
			$_from = db_get_one($q);
			$_ap = mime_address_parse($_from);
			$_ap['address'] = trim($_ap['address']);
			if ($_ap['address'] != '' && isemail($_ap['address']) && array_search($_ap['address'], $mf_from_addr) === false)		// ּҿ ߺ ּҴ .
			{
				$mf_from[] = $_from;
				$mf_from_addr[] = $_ap['address'];
			} else
			{
				$mf_from_ori[] = $_from;
			}	// if()
		}	// for()

		if (sizeof($mf_from_addr) > 0)
		{
			// as_exec_text - 4 , 4| , 4||
			$q = "
				SELECT
					*
				FROM
					" . $TB['AUTO_FILTER'] . "
				WHERE
					m_no='" . $AUTH['auth_m_no'] . "'
					AND as_name LIKE '" . $G_SYS['AUTO_FILTER_PREFIX'] . "%'
					AND as_condition LIKE '%FROM%'
					AND as_exec LIKE '%MOVE%'
					AND (as_exec_text = '" . $_POST['sel_mail_box'] . "' OR as_exec_text LIKE '" . $_POST['sel_mail_box'] . "|%')
				";
			$row = db_get_row($q);
			if (!$row)		// ߰
			{
				// ִ   .
					limit_auto_filter_max();

				// set
					$q = "SELECT mb_name FROM ".$TB['MAIL_BOX']." WHERE m_no='" . $AUTH['auth_m_no'] . "' AND mb_id='" . $_POST['sel_mail_box'] . "'";
					$mb_name = db_get_one($q);
					$_POST['as_name'] = to_db_str(addslashes($G_SYS['AUTO_FILTER_PREFIX'].$mb_name));
					$_POST['as_condition'] = 'FROM';
					$_text = str_replace('|', '', set_auto_filter_trim(implode(',', $mf_from_addr)));
					$_POST['as_condition_text'] = to_db_str(addslashes($_text));
					$_POST['as_exec'] = 'MOVE';
					$_POST['as_exec_text'] = to_db_str($_POST['sel_mail_box']);
					$sql = "SELECT MAX(as_sort) FROM ".$TB['AUTO_FILTER']." WHERE m_no='" . $AUTH['auth_m_no'] . "'";
					$_POST['as_sort'] = db_get_one($sql) + 1;


				// data
					$sql = "
						INSERT INTO
							" .	$TB['AUTO_FILTER']	. "
							( as_no , m_no , as_name , as_condition , as_condition_text , as_exec , as_exec_text , as_econdition , as_econdition_text , as_is_use , as_sort )
						VALUES
							( ".db_sqc_next($TB['AUTO_FILTER']).", '" . $AUTH['auth_m_no'] . "', '" . $_POST['as_name'] . "', '" . $_POST['as_condition'] . "', '" . $_POST['as_condition_text'] . "', '" . $_POST['as_exec'] . "', '" . $_POST['as_exec_text'] . "', '', '', 'Y', '" . $_POST['as_sort'] . "' )
						";
					db_query($sql);

					$msg = " ڵз [".$_POST['as_name']."] Ģ  ߰Ǿϴ.\\n\\n";						
					$msg .= "- ߰ ּ :\\n".implode(", ", $mf_from)."\\n\\n";
			} else		// 
			{
				//   м
				$as = get_auto_filter_vars();
				$_ex = explode('|', $row['as_condition']);
				$_ex2 = explode('|', $row['as_condition_text']);
				$view['as_condition_ischk'] = array();
				$view['as_condition_value'] = array();
				foreach ($as['condition'] as $key=>$val)
				{
					$_as = array_search($key, $_ex);
					if ($_as !== false)
					{
						$view['as_condition_ischk'][$key] = true;
						$view['as_condition_value'][$key] = $_ex2[$_as];
					}	// if()
				}	// foreach()

				//  ˻ ߺ  ּҸ ߰.
				if ($view['as_condition_value']['FROM'] != '')		//  ϵ ּҰ 
				{
					$_ex = explode(',', $view['as_condition_value']['FROM']);
					for ($i=0; $i<sizeof($mf_from_addr); $i++)
					{
						if (array_search($mf_from_addr[$i], $_ex) === false)		// ߰Ϸ ּҰ ϵ ʾ 
						{
							$view['as_condition_value']['FROM'] .= ','.$mf_from_addr[$i];
							$mf_from_insert[] = $mf_from[$i];
						} else
						{
							$mf_from_exists[] = $mf_from[$i];
						}	// if()
					}	// for()
				} else
				{
					$view['as_condition_value']['FROM'] .= ','.implode(',', $mf_from_addr);
				}	// if()

				//  Ŀ ° ȯ.
				$_POST['as_condition_text'] = '';
				$i = 0;
				foreach ($view['as_condition_value'] as $key=>$val)
				{
					$_POST['as_condition_text'] .= str_replace('|', '', set_auto_filter_trim($val));
					if ($i+1 != sizeof($view['as_condition_value']))
						$_POST['as_condition_text'] .= '|';
					$i++;
				}	// foreach()
				$_POST['as_condition_text'] = to_db_str(addslashes($_POST['as_condition_text']));

				// length cechk
				if (strlen($_POST['as_condition_text']) > $G_SYS['DB_TEXT'])
					msg("  ڵз ϵ ּҵ  ̰ ".number_format($G_SYS['DB_TEXT'])."ڸ ʰϿϴ.\\n\\nó  ڵз ̸   ٽ Ͻø ο ڵз Ģ Ǿ  ذ˴ϴ.\\n\\n [ȯ漳 -  ڵз] [".$row['as_name']."]Ģ ̸  \"".$G_SYS['AUTO_FILTER_PREFIX']."\" ܾ ٸ ܾ Ͻø ˴ϴ.");

				// data
					if ($_POST['as_condition_text'] != $row['as_condition_text'])
					{				
						$q = "
							UPDATE
								" . $TB['AUTO_FILTER'] . "
							SET
								as_condition_text='" . $_POST['as_condition_text'] . "'
							WHERE
								as_no='" . $row['as_no'] . "'
								AND m_no='" . $AUTH['auth_m_no'] . "'
							";
						db_query($q);

						$msg = " ڵз [".$row['as_name']."] Ģ Ǿϴ.\\n\\n";						
					} else 
					{
						$msg = " ڵз [".$row['as_name']."] Ģ  ʾҽϴ.\\n\\n";						
					}	// if()
				if (sizeof($mf_from_insert) > 0)
					$msg .= "- ߰ ּ :\\n".implode(", ", $mf_from_insert)."\\n\\n";
				if (sizeof($mf_from_exists) > 0)
					$msg .= "-  ּ(̹ ϵǾ ) :\\n".implode(", ", $mf_from_exists)."\\n\\n";
			}	// if()
		} else
		{
			$msg = "Ͻ ϵ ּҰ Ȯ ʾƼ  ڵз ϵ ʾҽϴ.\\n\\n";
			$msg .= "-  ּ :\\n".implode(", ", $mf_from_ori)."\\n\\n";
		}	// if()
	}	// if()


//  ̵
	// set file
	$UPLOAD_ROOT = get_mail_dir();
	$errorMsg = '';

	if ($_POST['mb_id'] != $_POST['sel_mail_box'])
	{
		$mb_dir_src = get_mb_dir($_POST['mb_id']);
		$mb_dir_dest = get_mb_dir($_POST['sel_mail_box']);
		for ($i=0; $i<sizeof($mf_no); $i++)
		{
			// file move
				if ($mb_dir_src != $mb_dir_dest)
				{
					$row = db_get_row("SELECT mf_filename, mfext1 FROM " . $mail_file_table . " WHERE mf_no='" . $mf_no[$i] . "' AND m_no='" . $AUTH['auth_m_no'] . "' AND mb_id='". $_POST['mb_id']. "'");
					// [2006-01-05][custmize] /Ȯ .
					if ($row['mfext1'] != 'Y')
					{
						if (!$row['mf_filename'])
							msg(" ʴ Դϴ.\\n\\n̹ Ǿų ٸ  Ű  ֽϴ.");
						$errorMsg .= file_move($row['mf_filename'], '', $mb_dir_src, $row['mf_filename'], '', $mb_dir_dest, false);
					}	// if()
				}	// if()
		}	// for()

		// db update
			// [2006-01-05][custmize] /Ȯ .
			$q_where = " AND ( mfext1 != 'Y' OR mfext1 IS NULL ) ";

			$q_mf_no = set_array2comma(" (", ") ", $mf_no);
			$sql = "
				UPDATE
					$mail_file_table
				SET
					mb_id='" . $_POST['sel_mail_box'] . "'
				WHERE
					mf_no IN ".$q_mf_no."
					AND m_no='" . $AUTH['auth_m_no'] . "'
					AND mb_id='". $_POST['mb_id']. "'
					$q_where
				";
			db_query($sql);
		#$msg = "Ͻ ϵ [".get_mb_name($_POST['sel_mail_box'])."]() ̵Ǿϴ.";
	} else
	{
		//$msg .= " δ ̵  ϴ.";
	}	// if()


// end
	if ($errorMsg)
	{
		page_loading_view_hidden();
		error($errorMsg, 'FILE', false);
		$_time = 3;
	} else
	{
		$_time = 0;
	}	// if()
	if ($msg)
		msg($msg, 0);
	movepage('mail_list.php?mb_id=' . $_POST['mb_id'] . '&' . get_qs('mb_id', 'mf_no', 'sel_mail_box', 'sel_mail_box_2'), $_time);

require_once('include/global_end.php');
?>

==> nmail-php-patch-2.5.2-to-2.6.1.tgz: nmail/mail_move_ok.php <==
<?
require_once('include/global.php');
require_once('include/mail_lib.php');
require_once('include/file.php');
require_once('conf.inc.php');

page_loading_view(" ̵ϰ ֽϴ.");

// check
	// б⿡ ̵
	if (!$_POST && $_GET)
		$_POST = $_GET;

	if (!$_POST['mb_id'] || (!$_POST['mf_no'] && !$_POST['cmf']) || !$_POST['sel_mail_box'])
		msg('ùٸ URL Ͽ ֽʽÿ');


// data
	// set data
		$mail_file_table = $AUTH[auth_m_mf_table];

	$mf_no = array();
	if (getarraycount($_POST['cmf']) > 0)
	{
		$mf_no = $_POST['cmf'];
	} else
	{
		$mf_no[] = $_POST['mf_no'];
	}	// if()


// [2007-11-15]  ڵз
	$msg = '';
	// [2011-03-29] ̵ ư ߰
	//if ($_POST['cmd'] == 'AUTO_FILTER')
	if ($_POST['cmd'] == 'AUTO_FILTER' || $_GET['cmd'] == 'AUTO_FILTER')
	{
		require_once('include/auto_filter_lib.php');

		//  ϵ ּ 
		$mf_from = array();
		$mf_from_ori = array();
		$mf_from_addr = array();
		$mf_from_insert = array();
		$mf_from_exists = array();
		for ($i=0; $i<sizeof($mf_no); $i++)
		{
			$q = "SELECT mf_from FROM " . $mail_file_table . " WHERE mf_no='" . $mf_no[$i] . "' AND m_no='" . $AUTH['auth_m_no'] . "' AND mb_id='". $_POST['mb_id']. "'";
			$_from = db_get_one($q);
			$_ap = mime_address_parse($_from);
			$_ap['address'] = trim($_ap['address']);
			if ($_ap['address'] != '' && isemail($_ap['address']) && array_search($_ap['address'], $mf_from_addr) === false)		// ּҿ ߺ ּҴ .
			{
				$mf_from[] = $_from;
				$mf_from_addr[] = $_ap['address'];
			} else
			{
				$mf_from_ori[] = $_from;
			}	// if()
		}	// for()

		if (sizeof($mf_from_addr) > 0)
		{
			// as_exec_text - 4 , 4| , 4||
			$q = "
				SELECT
					*
				FROM
					" . $TB['AUTO_FILTER'] . "
				WHERE
					m_no='" . $AUTH['auth_m_no'] . "'
					AND as_name LIKE '" . $G_SYS['AUTO_FILTER_PREFIX'] . "%'
					AND as_condition LIKE '%FROM%'
					AND as_exec LIKE '%MOVE%'
					AND (as_exec_text = '" . $_POST['sel_mail_box'] . "' OR as_exec_text LIKE '" . $_POST['sel_mail_box'] . "|%')
				";
			$row = db_get_row($q);
			if (!$row)		// ߰
			{
				// ִ   .
					// [2011-03-29] ̵ ư ߰
					//limit_auto_filter_max();
					$sql = "
						SELECT
							COUNT(*)
						FROM
							" . $TB['AUTO_FILTER'] . "
						WHERE
							m_no='" . $AUTH['auth_m_no'] . "'
						";
					$as_cnt = db_get_one($sql);
					if ($as_cnt >= $G_SYS['AUTO_FILTER_MAX'])
					{
						?>
							<script type="text/javascript">
							<!--
								if (confirm("[̵]  ڵз  Ͽϴ.\n\nʿ 'ڵз'׸ ؾ մϴ.\n\n[ȯ漳 -  ڵз] ̵Ͻðڽϱ?"))
								{
									location.replace("<?= $nmpath ?>/auto_filter_list.php");
								} else
								{
									history.back();
									
								}
							//-->
							</script>
						<?
						exit;
					}	// if()

				// set
					$q = "SELECT mb_name FROM ".$TB['MAIL_BOX']." WHERE m_no='" . $AUTH['auth_m_no'] . "' AND mb_id='" . $_POST['sel_mail_box'] . "'";
					$mb_name = db_get_one($q);
					$_POST['as_name'] = to_db_str(addslashes($G_SYS['AUTO_FILTER_PREFIX'].$mb_name));
					$_POST['as_condition'] = 'FROM';
					$_text = str_replace('|', '', set_auto_filter_trim(implode(',', $mf_from_addr)));
					$_POST['as_condition_text'] = to_db_str(addslashes($_text));
					$_POST['as_exec'] = 'MOVE';
					$_POST['as_exec_text'] = to_db_str($_POST['sel_mail_box']);
					$sql = "SELECT MAX(as_sort) FROM ".$TB['AUTO_FILTER']." WHERE m_no='" . $AUTH['auth_m_no'] . "'";
					$_POST['as_sort'] = db_get_one($sql) + 1;


				// data
					$sql = "
						INSERT INTO
							" .	$TB['AUTO_FILTER']	. "
							( as_no , m_no , as_name , as_condition , as_condition_text , as_exec , as_exec_text , as_econdition , as_econdition_text , as_is_use , as_sort )
						VALUES
							( ".db_sqc_next($TB['AUTO_FILTER']).", '" . $AUTH['auth_m_no'] . "', '" . $_POST['as_name'] . "', '" . $_POST['as_condition'] . "', '" . $_POST['as_condition_text'] . "', '" . $_POST['as_exec'] . "', '" . $_POST['as_exec_text'] . "', '', '', 'Y', '" . $_POST['as_sort'] . "' )
						";
					db_query($sql);

					$msg = " ڵз [".$_POST['as_name']."] Ģ  ߰Ǿϴ.\\n\\n";						
					$msg .= "- ߰ ּ :\\n".implode(", ", $mf_from)."\\n\\n";
			} else		// 
			{
				//   м
				$as = get_auto_filter_vars();
				$_ex = explode('|', $row['as_condition']);
				$_ex2 = explode('|', $row['as_condition_text']);
				$view['as_condition_ischk'] = array();
				$view['as_condition_value'] = array();
				foreach ($as['condition'] as $key=>$val)
				{
					$_as = array_search($key, $_ex);
					if ($_as !== false)
					{
						$view['as_condition_ischk'][$key] = true;
						$view['as_condition_value'][$key] = $_ex2[$_as];
					}	// if()
				}	// foreach()

				//  ˻ ߺ  ּҸ ߰.
				if ($view['as_condition_value']['FROM'] != '')		//  ϵ ּҰ 
				{
					$_ex = explode(',', $view['as_condition_value']['FROM']);
					for ($i=0; $i<sizeof($mf_from_addr); $i++)
					{
						if (array_search($mf_from_addr[$i], $_ex) === false)		// ߰Ϸ ּҰ ϵ ʾ 
						{
							$view['as_condition_value']['FROM'] .= ','.$mf_from_addr[$i];
							$mf_from_insert[] = $mf_from[$i];
						} else
						{
							$mf_from_exists[] = $mf_from[$i];
						}	// if()
					}	// for()
				} else
				{
					$view['as_condition_value']['FROM'] .= ','.implode(',', $mf_from_addr);
				}	// if()

				//  Ŀ ° ȯ.
				$_POST['as_condition_text'] = '';
				$i = 0;
				foreach ($view['as_condition_value'] as $key=>$val)
				{
					$_POST['as_condition_text'] .= str_replace('|', '', set_auto_filter_trim($val));
					if ($i+1 != sizeof($view['as_condition_value']))
						$_POST['as_condition_text'] .= '|';
					$i++;
				}	// foreach()
				$_POST['as_condition_text'] = to_db_str(addslashes($_POST['as_condition_text']));

				// length cechk
				if (strlen($_POST['as_condition_text']) > $G_SYS['DB_TEXT'])
					msg("  ڵз ϵ ּҵ  ̰ ".number_format($G_SYS['DB_TEXT'])."ڸ ʰϿϴ.\\n\\nó  ڵз ̸   ٽ Ͻø ο ڵз Ģ Ǿ  ذ˴ϴ.\\n\\n [ȯ漳 -  ڵз] [".$row['as_name']."]Ģ ̸  \"".$G_SYS['AUTO_FILTER_PREFIX']."\" ܾ ٸ ܾ Ͻø ˴ϴ.");

				// data
					if ($_POST['as_condition_text'] != $row['as_condition_text'])
					{				
						$q = "
							UPDATE
								" . $TB['AUTO_FILTER'] . "
							SET
								as_condition_text='" . $_POST['as_condition_text'] . "'
							WHERE
								as_no='" . $row['as_no'] . "'
								AND m_no='" . $AUTH['auth_m_no'] . "'
							";
						db_query($q);

						$msg = " ڵз [".$row['as_name']."] Ģ Ǿϴ.\\n\\n";						
					} else 
					{
						$msg = " ڵз [".$row['as_name']."] Ģ  ʾҽϴ.\\n\\n";						
					}	// if()
				if (sizeof($mf_from_insert) > 0)
					$msg .= "- ߰ ּ :\\n".implode(", ", $mf_from_insert)."\\n\\n";
				if (sizeof($mf_from_exists) > 0)
					$msg .= "-  ּ(̹ ϵǾ ) :\\n".implode(", ", $mf_from_exists)."\\n\\n";
			}	// if()
		} else
		{
			$msg = "Ͻ ϵ ּҰ Ȯ ʾƼ  ڵз ϵ ʾҽϴ.\\n\\n";
			$msg .= "-  ּ :\\n".implode(", ", $mf_from_ori)."\\n\\n";
		}	// if()
	}	// if()


//  ̵
	// set file
	$UPLOAD_ROOT = get_mail_dir();
	$errorMsg = '';

	if ($_POST['mb_id'] != $_POST['sel_mail_box'])
	{
		$mb_dir_src = get_mb_dir($_POST['mb_id']);
		$mb_dir_dest = get_mb_dir($_POST['sel_mail_box']);
		for ($i=0; $i<sizeof($mf_no); $i++)
		{
			// file move
				if ($mb_dir_src != $mb_dir_dest)
				{
					$row = db_get_row("SELECT mf_filename, mfext1 FROM " . $mail_file_table . " WHERE mf_no='" . $mf_no[$i] . "' AND m_no='" . $AUTH['auth_m_no'] . "' AND mb_id='". $_POST['mb_id']. "'");
					// [2006-01-05][custmize] /Ȯ .
					if ($row['mfext1'] != 'Y')
					{
						if (!$row['mf_filename'])
							msg(" ʴ Դϴ.\\n\\n̹ Ǿų ٸ  Ű  ֽϴ.");
						$errorMsg .= file_move($row['mf_filename'], '', $mb_dir_src, $row['mf_filename'], '', $mb_dir_dest, false);
					}	// if()
				}	// if()
		}	// for()

		// db update
			// [2006-01-05][custmize] /Ȯ .
			$q_where = " AND ( mfext1 != 'Y' OR mfext1 IS NULL ) ";

			$q_mf_no = set_array2comma(" (", ") ", $mf_no);
			$sql = "
				UPDATE
					$mail_file_table
				SET
					mb_id='" . $_POST['sel_mail_box'] . "'
				WHERE
					mf_no IN ".$q_mf_no."
					AND m_no='" . $AUTH['auth_m_no'] . "'
					AND mb_id='". $_POST['mb_id']. "'
					$q_where
				";
			db_query($sql);
		#$msg = "Ͻ ϵ [".get_mb_name($_POST['sel_mail_box'])."]() ̵Ǿϴ.";
	} else
	{
		//$msg .= " δ ̵  ϴ.";
	}	// if()


// end
	if ($errorMsg)
	{
		page_loading_view_hidden();
		error($errorMsg, 'FILE', false);
		$_time = 3;
	} else
	{
		$_time = 0;
	}	// if()
	if ($msg)
		msg($msg, 0);
	movepage('mail_list.php?mb_id=' . $_POST['mb_id'] . '&' . get_qs('mb_id', 'mf_no', 'sel_mail_box', 'sel_mail_box_2', 'cmd', 'cmd_2'), $_time);

require_once('include/global_end.php');
?>
